| Title: | Words Used in Portuguese Wikipedia |
|---|---|
| Description: | Contains a dataset of words used in 15.000 randomly extracted pages from the Portuguese Wikipedia (<https://pt.wikipedia.org/>). |
| Authors: | Daniel Falbel [aut, cre] |
| Maintainer: | Daniel Falbel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-05-17 06:18:52 UTC |
| Source: | https://github.com/dfalbel/ptwikiwords |
Dataset containing words found when randomly downloaded 12.000 pages from https://pt.wikipedia.org/.
ptwikiwordsptwikiwords
A data frame with 146444 rows and 3 variables:
word, as is, found in Wikipedia pages
number of times the word was found in the sample of Wikipedia pages
wheter the word exists in the portuguese language (hunspell_check result)